@@ -228,7 +228,8 @@ class MechModel:
         # print('X.columns: ', X.columns)
         X = self.autofeat.transform(X)
         # print(X)
-        X = X.values
+
+        # X = X.values
 
         if X.shape[0]==1:
             sl = np.isnan(X)
