@@ -62,6 +62,34 @@ class DB_Connector:
             self.cursor.execute(query, (int(model_id), int(column_id)))
         self.conn.commit()
 
+    def insert_filtered_samples(self,
+                    model_id:int, num_of_samples:int):
+
+        metric_id = read_sql_query('''select metric_id from Metrics
+                                    where name=\'Filtered samples\'''', self.conn).iloc[0][0]
+        target_id = self.get_target_id('MOCKUP')
+        now_time = datetime.now()
+
+        query = '''insert into
+                    MetricToModels(model_id, target_id,
+                    metric_id, value, time)
+                    values (%s, %s, %s, %s, %s)'''
+        self.cursor.execute(query, (int(model_id), int(target_id),
+                                    int(metric_id), num_of_samples,
+                                    now_time))
+        self.conn.commit()
+
+    def get_last_filtered_samples(self, model_id:int):
+        metric_id = read_sql_query('''select metric_id from Metrics
+                                    where name=\'Filtered samples\'''', self.conn).iloc[0][0]
+
+        query = f'select * from MetricToModels WHERE model_id={model_id} and metric_id={metric_id}'
+        df = read_sql_query(query, self.conn)
+
+        metric = df[df.time==df.time.max()].value.iloc[0]
+
+        return int(metric)
+
     def insert_metrics(self, model_id:int,
                        metrics: dict[str, dict[str, str]],
                        target:str):
